==> youtui-center-api-0.0.1.7-lichao3-20180704.025617-1-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiGuidePageDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import java.io.Serializable;
import java.util.Date;

/**
 * 友推直投页dto
 * @author lichao 2018/6/11
 */
public class YoutuiGuidePageDto implements Serializable {

    private Long id;

    /** 标题 */
    private String title;

    /** 直投页类型 */
    private Integer pageType;

    /** 皮肤id */
    private Long skinId;

    private Integer isDeleted;

    /** 浮标id,暂时无作用 */
    private String buoyList;

    private Date gmtCreate;

    private Date gmtModified;

    private String extInfo;

    /** 玩法说明 */
    private String instruction;

    /** app内展示的素材图片 */
    private String appMaterialImg;

    /** app内玩法说明图片 */
    private String appInstructionImg;

    /** subTitle:活动副标题. */
    private String subTitle;

    /** 微信分享快照图片. */
    private String wxSnapshotImg;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public String getBuoyList() {
        return buoyList;
    }

    public void setBuoyList(String buoyList) {
        this.buoyList = buoyList;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }

    public String getInstruction() {
        return instruction;
    }

    public void setInstruction(String instruction) {
        this.instruction = instruction;
    }

    public String getAppMaterialImg() {
        return appMaterialImg;
    }

    public void setAppMaterialImg(String appMaterialImg) {
        this.appMaterialImg = appMaterialImg;
    }

    public String getAppInstructionImg() {
        return appInstructionImg;
    }

    public void setAppInstructionImg(String appInstructionImg) {
        this.appInstructionImg = appInstructionImg;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }

    public String getWxSnapshotImg() {
        return wxSnapshotImg;
    }

    public void setWxSnapshotImg(String wxSnapshotImg) {
        this.wxSnapshotImg = wxSnapshotImg;
    }
}

==> youtui-center-api-0.0.1.11-lichao1-20180725.124233-4-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiGuidePageDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import java.io.Serializable;
import java.util.Date;

/**
 * 友推直投页dto
 * @author lichao 2018/6/11
 */
public class YoutuiGuidePageDto implements Serializable {

    private Long id;

    /** 标题 */
    private String title;

    /** 直投页类型 */
    private Integer pageType;

    /** 皮肤id */
    private Long skinId;

    private Integer isDeleted;

    /** 浮标id,暂时无作用 */
    private String buoyList;

    private Date gmtCreate;

    private Date gmtModified;

    private String extInfo;

    /** 玩法说明 */
    private String instruction;

    /** app内展示的素材图片 */
    private String appMaterialImg;

    /** app内玩法说明图片 */
    private String appInstructionImg;

    /** subTitle:活动副标题. */
    private String subTitle;

    /** h5标题 **/
    private String h5Title;
    /**
     * 微信分享图片
     **/
    private String wxShareImg;
    /**
     * 微信分享标题
     **/
    private String wxShareTitle;
    /**
     * 微信分享信息
     **/
    private String wxShareInfo;

    /** 微信分享快照图片. */
    private String wxSnapshotImg;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public String getBuoyList() {
        return buoyList;
    }

    public void setBuoyList(String buoyList) {
        this.buoyList = buoyList;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }

    public String getInstruction() {
        return instruction;
    }

    public void setInstruction(String instruction) {
        this.instruction = instruction;
    }

    public String getAppMaterialImg() {
        return appMaterialImg;
    }

    public void setAppMaterialImg(String appMaterialImg) {
        this.appMaterialImg = appMaterialImg;
    }

    public String getAppInstructionImg() {
        return appInstructionImg;
    }

    public void setAppInstructionImg(String appInstructionImg) {
        this.appInstructionImg = appInstructionImg;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }

    public String getH5Title() {
        return h5Title;
    }

    public void setH5Title(String h5Title) {
        this.h5Title = h5Title;
    }

    public String getWxShareImg() {
        return wxShareImg;
    }

    public void setWxShareImg(String wxShareImg) {
        this.wxShareImg = wxShareImg;
    }

    public String getWxShareTitle() {
        return wxShareTitle;
    }

    public void setWxShareTitle(String wxShareTitle) {
        this.wxShareTitle = wxShareTitle;
    }

    public String getWxShareInfo() {
        return wxShareInfo;
    }

    public void setWxShareInfo(String wxShareInfo) {
        this.wxShareInfo = wxShareInfo;
    }

    public String getWxSnapshotImg() {
        return wxSnapshotImg;
    }

    public void setWxSnapshotImg(String wxSnapshotImg) {
        this.wxSnapshotImg = wxSnapshotImg;
    }
}
